@@ -115,7 +115,7 @@ class Data_inegrator:
                 for patient_train_batch in self.xy_train_dataloader:
                     field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
                     # If for some reason the batch has mor dimensions than expected, squeeze it.
-                    if len(field0_batch.shape > 2):
+                    if len(field0_batch.shape) > 2:
                         field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch[
                             'FIELD1'].squeeze()
 
@@ -164,7 +164,11 @@ class Data_inegrator:
             for patient in self.patients_dataset:
                 if patient.get_status() == 0:
                     field0, field1 = patient.field0, patient.field1
-                    latent_representation = full_vae.xyvae(torch.cat([field0, field1], dim=0))[4]
+                    try:
+                        latent_representation = full_vae.xyvae(torch.cat([field0, field1], dim=0))[4]
+                    except RuntimeError:
+                        latent_representation = full_vae.xyvae(torch.cat([field0, field1], dim=1))[4]
+
                 elif patient.get_status() == 1:
                     field0 = patient.field0
                     latent_representation = full_vae.xvae(field0)[4]
