@@ -29,7 +29,7 @@ class patient_dataset(Dataset):
         self.dict_retrieval_flag = 1
         self.transform = transform
         patients_list = []
-        if not isinstance(patient_id_name, Iterable):
+        if sample_type_name is not None:
             merged_df = pd.concat(
                 [otu_df, mapping_table[patient_id_name], mapping_table[time_name], mapping_table[sample_type_name]],
                 axis=1)
@@ -48,10 +48,13 @@ class patient_dataset(Dataset):
             all_unique_patient_ids = set.union(*[set(specific_mapping_table[specific_patient_id_name]) for
                                                  specific_mapping_table, specific_patient_id_name in
                                                  zip(mapping_table, patient_id_name)])
-            all_unique_tp = set.union(*[set(specific_mapping_table[time]) for
-                                        specific_mapping_table, time in
-                                        zip(mapping_table, time_name)])
+
             for patient_id in all_unique_patient_ids:
+
+                all_unique_tp=set.union(*[set(specific_mapping_table[specific_mapping_table[specific_patient_id_name]==patient_id][time]) for
+                            specific_mapping_table,specific_patient_id_name, time in
+                            zip(mapping_table,patient_id_name,time_name)])
+
                 for tp in all_unique_tp:
                     patient_dict = {}
                     for i, (specific_otu, specific_mapping_table, patient_col_name, tp_col_name) in enumerate(
@@ -59,9 +62,9 @@ class patient_dataset(Dataset):
                         current_microbiome_sample = specific_otu[
                             (specific_mapping_table[patient_col_name] == patient_id) & (specific_mapping_table[
                                                                                             tp_col_name] == tp)]
-                        if i == 0 and current_microbiome_sample is not None:
+                        if i == 0 and not current_microbiome_sample.empty:
                             patient_dict['FIELD0'] = current_microbiome_sample
-                        elif i == 1 and current_microbiome_sample is not None:
+                        elif i == 1 and not current_microbiome_sample.empty:
                             patient_dict['FIELD1'] = current_microbiome_sample
                     if bool(patient_dict):  # check if dictionary is not empty, which means that there is no samples
                         # for the given patient_id and tp.
