@@ -11,9 +11,9 @@ def parse_parameters(parser: argparse.ArgumentParser):
     parser.add_argument("results_path", type=_dir_path, help="The path to the folder in which the results should be "
                                                             "placed", default=os.getcwd())
 
-    parser.add_argument('-xy', '--xy_architecture', nargs='+', help='The architecture of the xy vae', type=str)
-    parser.add_argument('-x', '--x_architecture', nargs='+', help='The architecture of the x vae', type=str)
-    parser.add_argument('-y', '--y_architecture', nargs='+', help='The architecture of the y vae', type=str)
+    parser.add_argument('-xy', '--xy_architecture', nargs='+', help='The architecture of the xy vae', type=int)
+    parser.add_argument('-x', '--x_architecture', nargs='+', help='The architecture of the x vae', type=int)
+    parser.add_argument('-y', '--y_architecture', nargs='+', help='The architecture of the y vae', type=int)
     parser.add_argument('-t', '--train_size', type=float, help='The percentage of the train out of the whole data ',
                         default=0.8)
     parser.add_argument('-b', '--batch_size', type=int, help='The batch size of the train loader ', default=10)
